#
# spec file for package isync
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           isync
Version:        1.5.0
Release:        1.2
Summary:        Utility to synchronize IMAP mailboxes with local maildir folders
License:        GPL-2.0-only
URL:            https://isync.sourceforge.io/
Source:         https://prdownloads.sourceforge.net/isync/%{name}-%{version}.tar.gz
Source1:        https://prdownloads.sourceforge.net/isync/%{name}-%{version}.tar.gz.asc
Source2:        https://keyserver.ubuntu.com/pks/lookup?op=get&search=0x63bfd037cad71e8dff3aea3ac17714f08d1bdbba#/%{name}.keyring
BuildRequires:  db-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libsasl2)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(zlib)

%description
isync is a command line application which synchronizes mailboxes; currently
Maildir and IMAP4 mailboxes are supported. New messages, message deletions
and flag changes can be propagated both ways. isync is suitable for use in
IMAP-disconnected mode.

Synchronization is based on unique message identifiers (UIDs), so no
identification conflicts can occur (as opposed to some other mail
synchronizers). Synchronization state is kept in one local text file per
mailbox pair; multiple replicas of a mailbox can be maintained.

%prep
%autosetup -p1

%build
%configure
%make_build

%install
%make_install docdir=%{_docdir}/%{name}

%files
%license COPYING
%doc README AUTHORS ChangeLog NEWS
%{_bindir}/mbsync-get-cert
%{_bindir}/mbsync
%{_bindir}/mdconvert
%exclude %{_docdir}/%{name}/TODO
%{_docdir}/%{name}/examples/*
%dir %{_docdir}/%{name}/examples
%{_mandir}/man1/mbsync.1%{?ext_man}
%{_mandir}/man1/mdconvert.1%{?ext_man}

%changelog
* Wed Oct  9 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.5.0
  * Changed default config & state locations to follow the XDG basedir spec
  * Added support for IMAP mailbox names with non-ASCII characters
  * Added support for Maildir Paths with suffixes (not ending with a slash)
  * Made the Channel side to expire with MaxMessages configurable
  * MaxMessages and MaxSize can be used together now
  * The unfiltered list of mailboxes in each Store can be printed now
  * A proper summary is now printed prior to exiting.
  * Added support for mirroring deletions more accurately; option ExpungeSolo
  * Added new sync operation 'Old' to retry previously skipped messages
  * Added --ext-exit option to indicate with the exit code whether Stores
    were modified
  * Added support for the LITERAL- IMAP extension, which improves upload
    performance with f.ex. GMail somewhat
  * Improved error handling when attempting to store too big messages
  * Malformed messages with incomplete headers will be propagated now
  * A notice is now emitted if the server does not support race-free Trash
  * Improved checking for invalid command lines
  * Options not supported due to the build configuration are still recognized
    now, to make error messages more helpful
  * he progress indicator is rate-limited now
  * Added --dry-run option
  * Various improvements to the debugging output
  * Vastly extended the autotest suite
  * The reference point for relative local paths in the configuration file
    is now the file's containing directory
  * Maildir Path cannot be nested into Inbox anymore (this was never documented)
  * Renamed the ReNew/--renew/-N options to Upgrade/--upgrade/-u and
    Delete/--delete/-d to Gone/--gone/-g
  * Superseded SSLVersions option with TLSVersions, and disabled TLS v1.0
    and v1.1 by default
  * Renamed SSLType option to TLSType
  * Placeholders will be now created for messages exceeding MaxSize even if they
    are flagged on the source side
  * Placeholder upgrades no longer pull flag updates along unless also requested
  * New messages which we are about to expunge from the source side are not
    propaged any more even if the target side would keep them
  * Tunnel is now consistently assumed to be secure, so some warnings are gone
  * Worked around "unexpected EOF" error messages at end of TLS connections;
    affects f.ex. GMail
  * Worked around protocol corruption issue with iCloud (mail.me.com)
  * Fixed missing CAPABILITY command after logging in if the server does not
    report updated capabilities automatically (affects f.ex. MS Exchange)
  * Fixed CopyArrivalDate failing on some date strings
  * Fixed propagation of new messages to non-UIDPLUS servers
  * Fixed Timeout being ignored by DNS host resolution
  * Fixed broken Tunnel potentially causing SIGPIPE
  * Fixed Tunnel leaving behind zombie processes
  * Fixed expunges not being propagated at all if the first run after they
    occurred did not include --delete
  * Fixed MaxMessages being exceeded when only --new was used
  * Fixed messages being instantly expired despite being important when only
  - -new was used
  * Trash-ing failures now prevent expunging and cause a non-zero exit code
  * Fixed placeholders being needlessly trashed
  * Fixed TrashNewOnly and TrashRemoteNew omitting messages for which only
    a placeholder was synced
  * Fixed TrashRemoteNew omitting messages which exceed MaxSize
  * Fixed TrashRemoteNew not using race-free expunge
  * Optimized some places with unnecessarily high CPU usage
  * Fixed unnecessary network usage by non-selective uni-directional syncs when
    no placeholders are present
  * Fixed crash when Patterns yields nothing when built with new compilers
  * Fixed crash when all flag propagations to a mailbox failed
  * Fixed handling of errors during opening mailboxes
  * Removed useless "lost track of ... messages" warnings when resuming after
    an interruption
  * Fixed many minor bugs in corner cases, mostly when resuming after
    interruptions
- remove patch work-around-unexpected-EOF-error-messages-at-end-of-SSL-connections.patch
  as upstream integrated the patch
* Mon Feb 27 2023 Yifan Jiang <yfjiang@suse.com>
- Add patch work-around-unexpected-EOF-error-messages-at-end-of-SSL-connections.patch
  * Some mail servers do not send a close notification
    (SSL_shutdown()) before closing the TCP socket. This workaround
    makes isync handles the situation more gracefully (boo#1208166).
* Wed Jan  5 2022 Dirk Müller <dmueller@suse.com>
- update to 1.4.4 (bsc#1193376, bsc#1192985, CVE-2021-3657, CVE-2021-44143):
  * fixed CVE-2021-3657: multiple buffer overflows on excessively large
    IMAP literals
  * fixed CVE-2021-44143: buffer overflow on header-less messages
  * fixed crash on certain malformed messages in Maildirs
  * fixed somewhat spurious notice about conflicting changes on
    messages marked as deleted
* Wed Aug  4 2021 Dan Čermák <dcermak@suse.com>
- New upstream release 1.4.3
* Mon Jun  7 2021 Dan Čermák <dcermak@suse.com>
- New upstream release 1.4.2
  * This is a security update that fixes CVE-2021-3578
  1.4.2:
- fixed CVE-2021-3578: possible remote code execution
- fixed crash on invalid CAPABILITY response code
- tolerate INBOX mis-casing in Path setting
  1.4.1:
- fixed CVE-2021-20247
- fixed UIDVALIDITY change recovery potentially leading to data loss
- fixed spurious "unexpected FETCH response" errors with some servers
- worked around FastMail sending malformed PERMANENTFLAGS
* Sun Feb 28 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.3.5 (boo#1182488)
  * This is a security release that fixes CVE-2021-20247.
- Update to version 1.3.4
  This is a maintenance release that contains exactly one change:
  * fixed regression in handling NAMESPACE 'INBOX.', introduced in
    v1.3.2
* Wed Jan  6 2021 Dirk Müller <dmueller@suse.com>
- fix homepage url
* Tue Aug  4 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.3.3
  * Network timeout handling has been added.
  * Support for proper Maildir++ and a Maildir sub-folder naming
    style.
  * without extra dots have been added.
  * Support for TLS client certificates was added.
  * Support for recovering from baseless UID validity changes was
    added.
  * The get-cert script was renamed to mbsync-get-cert.
* Wed Jul  8 2020 Dan Čermák <dcermak@suse.com>
- Update to version 1.3.2
  - increased PassCmd buffer size to accomodate XOAUTH2 tokens
  - improved SSL error handling
  - improved resilience to IMAP server bugs relating to FETCH
  - fixed handling of non-uppercase IMAP iNbOx spellings
  - fixed timeouts while uploading big messages
  - fixed parsing of NIL hierarchy delimiters in IMAP LIST responses
  - fixed crash when using Tunnel in an IPv6-enabled build
  - fixed libcrypto detection from OpenSSL 1.1+ without pkg-config
  - made --debug-crash work with Yama ptrace protection
- use more scriptlets
- don't include COPYING twice and drop TODO from %%doc
- reenable gpg source verification
* Wed Feb 26 2020 Michal Hrusecky <michal.hrusecky@opensuse.org>
- drop sources signature as there is no published key to verify them
* Thu Jan 16 2020 Michal Hrusecky <michal.hrusecky@opensuse.org>
- Update to version 1.3.1
  - SSL now uses SNI, which for example GMail requires
  - fixed fallbacks for missing UIDPLUS extension (with e.g. DavMail)
  - fixed UIDVALIDITY recovery with really long Message-id headers
  - fixed GSSAPI authentication with Kerberos
  - fixed support for IMAP servers which do not sort search results (e.g.,
    poczta.o2.pl)
  - fixed CopyArrivalDate on platforms without glibc
  - fixed useless SASL warnings with certain plugins
  - the perl 5.14 requirement is now made explicit
  - improved OpenBSD support
  - fixed a bunch of compiler warnings
* Fri Dec 29 2017 crrodriguez@opensuse.org
- Update to version 1.3.0, fixes build against openSSL
  1.1.0, see https://sourceforge.net/projects/isync/files/isync/1.3.0
  for the full list of changes
* Thu Jun  2 2016 sleep_walker@opensuse.org
- add COPYING README AUTHORS ChangeLog to the package
* Fri May  6 2016 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Use pkgconfig() style dependencies
- Update dependencies
  * Enable sasl
* Mon Nov 16 2015 sleep_walker@opensuse.org
- bump to 1.2.1
  - fixed IPv6-enabled builds crashing upon host name resolution failure
  - fixed updating Maildir flags crashing on OpenBSD
  - fixed deadlocks with NFS home directories
  - fixed SASL authentication with GSS-API
  - fixed messages being uploaded again and again with some servers
  - fixed duplicate mailboxes with IMAP NAMESPACE "INBOX."
  - fixed some problems in the IMAP command submission code
  - fixed build with static libdb, libnsl, and libsocket
  - the dependencies on Berkeley DB and zlib (and the features they enable) can be explicitly disabled now
  - it is now possible to nest a Maildir Store's Path into its Inbox
  - fixed -DN not implying -Dn
- clean the spec with spec-cleaner
- add isync.keyring
* Mon Jul 27 2015 sleep_walker@opensuse.org
- bump to 1.2.0
  Changes:
  The 'isync' compatibility wrapper is now deprecated.
  An IMAP Path/NAMESPACE rooted in INBOX won't be handled specially
  any more. This means that some Patterns may need adjustment.
  The default output is a lot less verbose now.
  The meanings of the -V and -D options changed significantly.
  The SSL/TLS configuration has been re-designed. SSL is now
  explicitly enabled or disabled - "use SSL if available" is gone.
  Notice: Tunnels are assumed to be secure and thus default to no SSL.
  Support for SASL (flexible authentication) has been added.
  Support for Windows file systems has been added.
  Support for compressed data transfer has been added.
  Folder deletions can be propagated now.
* Thu Jan 23 2014 sleep_walker@suse.cz
- examples are installed automaticaly - remove manual copying from
  spec file
* Thu Jan 23 2014 sleep_walker@suse.cz
- license fix
* Thu Jan 23 2014 sleep_walker@suse.cz
- bump to 1.1.0
- drop isync-1.0.1_imaphierarchy.patch
* Fri Aug 24 2012 sleep_walker@suse.cz
- update to 1.0.5
* Thu Dec 16 2010 puzel@novell.com
- update to version 1.0.4
- fix some rpmlint warnings
- drop isync-1.0.1_missing_sentinel.patch (in upstream)
* Sun Jan 21 2007 mrueckert@suse.de
- update to version 1.0.3:
  - new option UseIMAPS to allow use of Tunnel-ed IMAPS servers
    without providing a dummy Host.
  - make config parsing more robust.
  - work around glibc printf bug.
  - fix crash with AltMap UID scheme.
  - compat wrapper: put INBOX under Maildir.
* Fri May 19 2006 mrueckert@suse.de
- update to 1.0.2
* Mon Mar 20 2006 mrueckert@suse.de
- build debuginfo package
- added patch for missing sentinel
* Sun Feb 19 2006 mrueckert@suse.de
- added isync-1.0.1_imaphierarchy.patch
  * without the patch you cant mirror imap hierarchies
    when using "Patterns"
* Sun Feb 19 2006 mrueckert@suse.de
- Initial package of version 1.0.1
